==> hinemos_src-4.0.0.tar.gz: HinemosClient/src_collectiverun/com/clustercontrol/collectiverun/view/action/CollectiveRunAction.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.collectiverun.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

import com.clustercontrol.bean.Property;
import com.clustercontrol.bean.PropertyConstant;
import com.clustercontrol.collectiverun.composite.ParameterViewComposite;
import com.clustercontrol.collectiverun.dialog.RunConfirmedDialog;
import com.clustercontrol.collectiverun.util.CollectiveRunEndpointWrapper;
import com.clustercontrol.collectiverun.util.RunPropertyUtil;
import com.clustercontrol.collectiverun.view.ParameterView;
import com.clustercontrol.util.Messages;
import com.clustercontrol.util.PropertyUtil;
import com.clustercontrol.ws.collectiverun.CollectiveRunInfo;
import com.clustercontrol.ws.collectiverun.InvalidRole_Exception;

/**
 * 一括制御を実行するアクションクラス<BR>
 * 
 * @version 1.0.0
 * @since 1.0.0
 * 
 */
public class CollectiveRunAction implements IViewActionDelegate {
	public static final String ID = "com.clustercontrol.collectiverun.accountcontrol.view.action.CollectiveRunAction";

	/** ビュー */
	private IViewPart viewPart = null;

	/**
	 * 
	 * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
	 */
	@Override
	public void init(IViewPart view) {
		viewPart = view;
	}

	/**
	 * 
	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
	 */
	@Override
	public void run(IAction action) {
		//プロパティシート
		ParameterView view = (ParameterView) this.viewPart
		.getAdapter(ParameterView.class);

		ParameterViewComposite parameterComposite = view.getComposite();
		Property data = parameterComposite.getInputData();
		String typeId = parameterComposite.getTypeId();
		String typeString = parameterComposite.getTypeString(typeId);

		if(typeId != null && typeString != null){
			// 実行確認ダイアログを表示する
			RunConfirmedDialog dialog = new RunConfirmedDialog(this.viewPart
					.getSite().getShell());
			PropertyUtil.setPropertyModify(data, PropertyConstant.MODIFY_NG);
			dialog.setDate(data);
			dialog.setType(typeString);

			// OKボタン押下
			if (dialog.open() == IDialogConstants.OK_ID) {
				//実行
				PropertyUtil.deletePropertyDefine(data);
				try {
					CollectiveRunInfo info = RunPropertyUtil.property2dto(typeId, data);
					CollectiveRunEndpointWrapper.run(typeId, info);

				} catch (Exception e) {
					String errMessage = "";
					if (e instanceof InvalidRole_Exception) {
						// アクセス権なしの場合、エラーダイアログを表示する
						MessageDialog.openInformation(null, Messages.getString("message"),
								Messages.getString("message.accesscontrol.16"));
					} else {
						errMessage = ", " + e.getMessage();
					}

					// 実行エラー時、エラーダイアログを表示する
					MessageDialog.openError(null, Messages.getString("message"),
							Messages.getString("message.collective.run.1") + errMessage);
				}

				parameterComposite.setInputData(data);
			}
			PropertyUtil.setPropertyModify(data, PropertyConstant.MODIFY_OK);
		}
	}

	/**
	 * 
	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
	 *      org.eclipse.jface.viewers.ISelection)
	 */
	@Override
	public void selectionChanged(IAction action, ISelection selection) {

	}
}

==> hinemos_src-4.1.3.tar.gz: HinemosClient/src_collectiverun/com/clustercontrol/collectiverun/view/action/CollectiveRunAction.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.collectiverun.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

import com.clustercontrol.bean.Property;
import com.clustercontrol.bean.PropertyDefineConstant;
import com.clustercontrol.collectiverun.composite.ParameterViewComposite;
import com.clustercontrol.collectiverun.dialog.RunConfirmedDialog;
import com.clustercontrol.collectiverun.util.CollectiveRunEndpointWrapper;
import com.clustercontrol.collectiverun.util.RunPropertyUtil;
import com.clustercontrol.collectiverun.view.ParameterView;
import com.clustercontrol.util.Messages;
import com.clustercontrol.util.PropertyUtil;
import com.clustercontrol.ws.collectiverun.CollectiveRunInfo;
import com.clustercontrol.ws.collectiverun.InvalidRole_Exception;

/**
 * 一括制御を実行するアクションクラス<BR>
 * 
 * @version 1.0.0
 * @since 1.0.0
 * 
 */
public class CollectiveRunAction implements IViewActionDelegate {
	public static final String ID = "com.clustercontrol.collectiverun.accountcontrol.view.action.CollectiveRunAction";

	/** ビュー */
	private IViewPart viewPart = null;

	/**
	 * 
	 * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
	 */
	@Override
	public void init(IViewPart view) {
		viewPart = view;
	}

	/**
	 * 
	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
	 */
	@Override
	public void run(IAction action) {
		//プロパティシート
		ParameterView view = (ParameterView) this.viewPart
				.getAdapter(ParameterView.class);

		ParameterViewComposite parameterComposite = view.getComposite();
		Property data = parameterComposite.getInputData();
		String typeId = parameterComposite.getTypeId();
		String typeString = parameterComposite.getTypeString(typeId);

		if(typeId != null && typeString != null){
			// 実行確認ダイアログを表示する
			RunConfirmedDialog dialog = new RunConfirmedDialog(this.viewPart
					.getSite().getShell());
			PropertyUtil.setPropertyModify(data, PropertyDefineConstant.MODIFY_NG);
			dialog.setDate(data);
			dialog.setType(typeString);

			// OKボタン押下
			if (dialog.open() == IDialogConstants.OK_ID) {
				//実行
				PropertyUtil.deletePropertyDefine(data);
				try {
					CollectiveRunInfo info = RunPropertyUtil.property2dto(typeId, data);
					CollectiveRunEndpointWrapper.run(typeId, info);

				} catch (Exception e) {
					String errMessage = "";
					if (e instanceof InvalidRole_Exception) {
						// アクセス権なしの場合、エラーダイアログを表示する
						MessageDialog.openInformation(null, Messages.getString("message"),
								Messages.getString("message.accesscontrol.16"));
					} else {
						errMessage = ", " + e.getMessage();
					}

					// 実行エラー時、エラーダイアログを表示する
					MessageDialog.openError(null, Messages.getString("message"),
							Messages.getString("message.collective.run.1") + errMessage);
				}

				parameterComposite.setInputData(data);
			}
			PropertyUtil.setPropertyModify(data, PropertyDefineConstant.MODIFY_OK);
		}
	}

	/**
	 * 
	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
	 *      org.eclipse.jface.viewers.ISelection)
	 */
	@Override
	public void selectionChanged(IAction action, ISelection selection) {

	}
}
